"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function promisifyStatementResult(stmt, method, field) {
    return (...params) => new Promise((resolve, reject) => {
        stmt[method](...params, function handler(error, r) {
            if (error) {
                reject(error);
                return;
            }
            const data = {
                result: this,
            };
            if (field && r) {
                data[field] = r;
            }
            resolve(data);
        });
    });
}
exports.promisifyStatementResult = promisifyStatementResult;
function promisifyStatementEach(stmt) {
    return (callback, ...params) => new Promise((resolve, reject) => {
        function cb(error, row) {
            if (error) {
                reject(error);
                return;
            }
            callback(row);
        }
        stmt.each(...params, cb, (error) => {
            if (error) {
                reject(error);
                return;
            }
            resolve({ result: this });
        });
    });
}
exports.promisifyStatementEach = promisifyStatementEach;
